NestedSingleChildScrollView class

Inheritance

Constructors

NestedSingleChildScrollView({Key? key, Axis scrollDirection = Axis.vertical, bool reverse = false, EdgeInsetsGeometry? padding, bool? primary, ScrollPhysics? physics, ScrollController? controller, Widget? child, DragStartBehavior dragStartBehavior = DragStartBehavior.start, Clip clipBehavior = Clip.hardEdge, HitTestBehavior hitTestBehavior = HitTestBehavior.opaque, String? restorationId, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, bool wantKeepAlive = true})
const

Properties

child → Widget?
The widget that scrolls.
finalinherited
clipBehavior → Clip
The content will be clipped (or not) according to this option.
finalinherited
controller → ScrollController?
An object that can be used to control the position to which this scroll view is scrolled.
finalinherited
dragStartBehavior → DragStartBehavior
Determines the way that drag start behavior is handled.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hitTestBehavior → HitTestBehavior
Defines the behavior of gesture detector used in this Scrollable.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardDismissBehavior → ScrollViewKeyboardDismissBehavior
The ScrollViewKeyboardDismissBehavior defines how this ScrollView will dismiss the keyboard automatically.
finalinherited
padding → EdgeInsetsGeometry?
The amount of space by which to inset the child.
finalinherited
physics → ScrollPhysics?
How the scroll view should respond to user input.
finalinherited
primary → bool?
Whether this is the primary scroll view associated with the parent PrimaryScrollController.
finalinherited
restorationId → String?
Restoration ID to save and restore the scroll offset of the scrollable.
finalinherited
reverse → bool
Whether the scroll view scrolls in the reading direction.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
The Axis along which the scroll view's offset increases.
finalinherited
wantKeepAlive → bool
是否缓存可滚动页面,不缓存可能导致页面在嵌套滚动时被销毁导致手势事件丢失
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited